==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeNotation.h <==
// class gnu.xml.libxmlj.dom.GnomeNotation

// class file dependencies
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 74e5daace68296f0 gnu_xml_libxmlj_dom_GnomeNotation
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeNotation_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeNotation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$refs	_jc_gnu_xml_libxmlj_dom_GnomeNotation$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeNotation$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object	_jc_gnu_xml_libxmlj_dom_GnomeNotation$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vtable	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vtype	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeNotation$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeNotation$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeNotation$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeNotation$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeNotation$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeNotation$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeNotation$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vmethods {
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *);
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vmethods	gnu_xml_libxmlj_dom_GnomeNotation;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_refs	gnu_xml_libxmlj_dom_GnomeNotation;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNotation;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object {
	_jc_gnu_xml_libxmlj_dom_GnomeNotation$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeNotation$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeNotation$vtype _jc_gnu_xml_libxmlj_dom_GnomeNotation$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeNotation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeNotation$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeNotation_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeNotation.h <==
// class gnu.xml.libxmlj.dom.GnomeNotation

// class file dependencies
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 74e5daace68296f0 gnu_xml_libxmlj_dom_GnomeNotation
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeNotation_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeNotation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$refs	_jc_gnu_xml_libxmlj_dom_GnomeNotation$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeNotation$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object	_jc_gnu_xml_libxmlj_dom_GnomeNotation$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vtable	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vtype	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeNotation$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeNotation$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeNotation$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeNotation$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeNotation$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeNotation$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeNotation$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vmethods {
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vmethods	gnu_xml_libxmlj_dom_GnomeNotation;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_refs	gnu_xml_libxmlj_dom_GnomeNotation;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeNotation$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNotation;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeNotation$object {
	_jc_gnu_xml_libxmlj_dom_GnomeNotation$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeNotation$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeNotation$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeNotation$vtype _jc_gnu_xml_libxmlj_dom_GnomeNotation$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeNotation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeNotation$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeNotation_H_ */
